.. image:: https://github.com/vorausrobotik/vdoc/actions/workflows/pipeline.yml/badge.svg
    :target: https://github.com/vorausrobotik/vdoc/actions/workflows/pipeline.yml
    :class: badge
.. image:: https://codecov.io/gh/vorausrobotik/vdoc/graph/badge.svg
    :target: https://codecov.io/gh/vorausrobotik/vdoc
    :class: badge
.. image:: https://img.shields.io/pypi/pyversions/vdoc
    :target: https://pypi.org/project/vdoc
    :class: badge
.. image:: https://img.shields.io/pypi/v/vdoc
    :target: https://pypi.org/project/vdoc
    :class: badge
.. image:: https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336
    :target: https://pycqa.github.io/isort/
    :class: badge
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
    :class: badge

####
vdoc
####

Multi version documentation hosting.


Documentation
#############

Please read the `documentation <https://vorausrobotik.github.io/vdoc/>`_ for more a more detailed introduction.
